==> members-facade-20240528-20240530.123736-7-sources.jar: com/bizvane/members/facade/models/po/UrMbrMoreBrandIntegralRecordPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class UrMbrMoreBrandIntegralRecordPO implements Serializable {
    /**
     * 只读. 主键id. more_brand_integral_record_id
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "主键id",name = "moreBrandIntegralRecordId")
    private Long moreBrandIntegralRecordId;

    /**
     * 只读. 企业id. sys_company_id
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "企业id",name = "sysCompanyId")
    private Long sysCompanyId;

    /**
     * 只读. 品牌id. brand_id
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "品牌id",name = "brandId")
    private Long brandId;

    /**
     * 只读. 会员code. member_code
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "会员code",name = "memberCode")
    private String memberCode;

    /**
     * 只读. 会员卡号. card_no
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "会员卡号",name = "cardNo")
    private String cardNo;

    /**
     * 只读. 会员手机号. phone
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "会员手机号",name = "phone")
    private String phone;

    /**
     * 只读. 流水code. record_code
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "流水code",name = "recordCode")
    private String recordCode;

    /**
     * 只读. 变更单据. change_bills
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变更单据",name = "changeBills")
    private String changeBills;

    /**
     * 只读. 变更积分. change_integral
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变更积分",name = "changeIntegral")
    private Integer changeIntegral;

    /**
     * 只读. 变动时间. change_date
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变动时间",name = "changeDate")
    private Date changeDate;

    /**
     * 只读. 变动类型1.支出,2.收入. change_way
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变动类型1.支出,2.收入",name = "changeWay")
    private String changeWay;

    /**
     * 只读. 变更详情. change_details
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变更详情",name = "changeDetails")
    private String changeDetails;

    /**
     * 只读. ur积分业务类型（1 赠送 2 消费 3退货  4 积分调整减积分  5 积分调整增积分  6 积分兑换　7 积分抵现  8积分抵现返还 9 积分清零 10 赠送退回 11 线下积分商城扣除 12 线下积分商城返还）. ur_offline_business_type
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "ur积分业务类型（1 赠送 2 消费 3退货  4 积分调整减积分  5 积分调整增积分  6 积分兑换　7 积分抵现  8积分抵现返还 9 积分清零 10 赠送退回 11 线下积分商城扣除 12 线下积分商城返还）",name = "urOfflineBusinessType")
    private String urOfflineBusinessType;

    /**
     * 只读. 原始变更单据. original_change_bills
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "原始变更单据",name = "originalChangeBills")
    private String originalChangeBills;

    /**
     * 只读. 冲正单据. reversal_change_bills
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "冲正单据",name = "reversalChangeBills")
    private String reversalChangeBills;

    /**
     * 只读. 变更状态，1待操作,2操作成功,3操作失败,4待冲正,5冲正中,6冲正成功. change_status
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变更状态，1待操作,2操作成功,3操作失败,4待冲正,5冲正中,6冲正成功",name = "changeStatus")
    private Integer changeStatus;

    /**
     * 只读. 变更状态描述. change_status_remark
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变更状态描述",name = "changeStatusRemark")
    private String changeStatusRemark;

    /**
     * 只读. 备注. remark
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "备注",name = "remark")
    private String remark;

    /**
     * 只读. 创建日期. create_date
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "创建日期",name = "createDate")
    private Date createDate;

    /**
     * 只读. 修改时间. modified_date
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "修改时间",name = "modifiedDate")
    private Date modifiedDate;

    /**
     * 只读. 数据有效性：1=有效；0=无效. valid
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "数据有效性：1=有效；0=无效",name = "valid")
    private Boolean valid;

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    private static final long serialVersionUID = 1L;

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Long getMoreBrandIntegralRecordId() {
        return moreBrandIntegralRecordId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setMoreBrandIntegralRecordId(Long moreBrandIntegralRecordId) {
        this.moreBrandIntegralRecordId = moreBrandIntegralRecordId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Long getBrandId() {
        return brandId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getMemberCode() {
        return memberCode;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode == null ? null : memberCode.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getCardNo() {
        return cardNo;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setCardNo(String cardNo) {
        this.cardNo = cardNo == null ? null : cardNo.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getPhone() {
        return phone;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setPhone(String phone) {
        this.phone = phone == null ? null : phone.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getRecordCode() {
        return recordCode;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setRecordCode(String recordCode) {
        this.recordCode = recordCode == null ? null : recordCode.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getChangeBills() {
        return changeBills;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeBills(String changeBills) {
        this.changeBills = changeBills == null ? null : changeBills.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Integer getChangeIntegral() {
        return changeIntegral;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeIntegral(Integer changeIntegral) {
        this.changeIntegral = changeIntegral;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Date getChangeDate() {
        return changeDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeDate(Date changeDate) {
        this.changeDate = changeDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getChangeWay() {
        return changeWay;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeWay(String changeWay) {
        this.changeWay = changeWay == null ? null : changeWay.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getChangeDetails() {
        return changeDetails;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeDetails(String changeDetails) {
        this.changeDetails = changeDetails == null ? null : changeDetails.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getUrOfflineBusinessType() {
        return urOfflineBusinessType;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setUrOfflineBusinessType(String urOfflineBusinessType) {
        this.urOfflineBusinessType = urOfflineBusinessType == null ? null : urOfflineBusinessType.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getOriginalChangeBills() {
        return originalChangeBills;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setOriginalChangeBills(String originalChangeBills) {
        this.originalChangeBills = originalChangeBills == null ? null : originalChangeBills.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getReversalChangeBills() {
        return reversalChangeBills;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setReversalChangeBills(String reversalChangeBills) {
        this.reversalChangeBills = reversalChangeBills == null ? null : reversalChangeBills.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Integer getChangeStatus() {
        return changeStatus;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getChangeStatusRemark() {
        return changeStatusRemark;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeStatusRemark(String changeStatusRemark) {
        this.changeStatusRemark = changeStatusRemark == null ? null : changeStatusRemark.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Date getModifiedDate() {
        return modifiedDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Boolean getValid() {
        return valid;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setValid(Boolean valid) {
        this.valid = valid;
    }
}

==> members-facade-20250416-20250522.105126-5-sources.jar: com/bizvane/members/facade/models/po/UrMbrMoreBrandIntegralRecordPO.java <==
package com.bizvane.members.facade.models.po;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

public class UrMbrMoreBrandIntegralRecordPO implements Serializable {
    /**
     * 只读. 主键id. more_brand_integral_record_id
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "主键id",name = "moreBrandIntegralRecordId")
    private Long moreBrandIntegralRecordId;

    /**
     * 只读. 企业id. sys_company_id
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "企业id",name = "sysCompanyId")
    private Long sysCompanyId;

    /**
     * 只读. 品牌id. brand_id
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "品牌id",name = "brandId")
    private Long brandId;

    /**
     * 只读. 会员code. member_code
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "会员code",name = "memberCode")
    private String memberCode;

    /**
     * 只读. 会员卡号. card_no
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "会员卡号",name = "cardNo")
    private String cardNo;

    /**
     * 只读. 会员手机号. phone
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "会员手机号",name = "phone")
    private String phone;

    /**
     * 只读. 积分流水唯一标识. points_id_unique
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "积分流水唯一标识",name = "pointsIdUnique")
    private String pointsIdUnique;

    /**
     * 只读. 变更单据. change_bills
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变更单据",name = "changeBills")
    private String changeBills;

    /**
     * 只读. 变更积分. change_integral
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变更积分",name = "changeIntegral")
    private Integer changeIntegral;

    /**
     * 只读. 变动时间. change_date
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变动时间",name = "changeDate")
    private Date changeDate;

    /**
     * 只读. 变动类型1.支出,2.收入. change_way
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变动类型1.支出,2.收入",name = "changeWay")
    private String changeWay;

    /**
     * 只读. 变更详情. change_details
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变更详情",name = "changeDetails")
    private String changeDetails;

    /**
     * 只读. ur积分业务类型（1 赠送 2 消费 3退货  4 积分调整减积分  5 积分调整增积分  6 积分兑换　7 积分抵现  8积分抵现返还 9 积分清零 10 赠送退回 11 线下积分商城扣除 12 线下积分商城返还）. ur_offline_business_type
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "ur积分业务类型（1 赠送 2 消费 3退货  4 积分调整减积分  5 积分调整增积分  6 积分兑换　7 积分抵现  8积分抵现返还 9 积分清零 10 赠送退回 11 线下积分商城扣除 12 线下积分商城返还）",name = "urOfflineBusinessType")
    private String urOfflineBusinessType;

    /**
     * 只读. 原始变更单据. original_change_bills
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "原始变更单据",name = "originalChangeBills")
    private String originalChangeBills;

    /**
     * 只读. 冲正单据. reversal_change_bills
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "冲正单据",name = "reversalChangeBills")
    private String reversalChangeBills;

    /**
     * 只读. 变更状态，1待操作,2操作成功,3操作失败,4待冲正,5冲正中,6冲正成功. change_status
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变更状态，1待操作,2操作成功,3操作失败,4待冲正,5冲正中,6冲正成功",name = "changeStatus")
    private Integer changeStatus;

    /**
     * 只读. 变更状态描述. change_status_remark
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "变更状态描述",name = "changeStatusRemark")
    private String changeStatusRemark;

    /**
     * 只读. 备注. remark
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "备注",name = "remark")
    private String remark;

    /**
     * 只读. 创建日期. create_date
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "创建日期",name = "createDate")
    private Date createDate;

    /**
     * 只读. 修改时间. modified_date
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "修改时间",name = "modifiedDate")
    private Date modifiedDate;

    /**
     * 只读. 数据有效性：1=有效；0=无效. valid
     *
     * @mbg.generated
     */
    @ApiModelProperty(value = "数据有效性：1=有效；0=无效",name = "valid")
    private Boolean valid;

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    private static final long serialVersionUID = 1L;

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Long getMoreBrandIntegralRecordId() {
        return moreBrandIntegralRecordId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setMoreBrandIntegralRecordId(Long moreBrandIntegralRecordId) {
        this.moreBrandIntegralRecordId = moreBrandIntegralRecordId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Long getBrandId() {
        return brandId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getMemberCode() {
        return memberCode;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode == null ? null : memberCode.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getCardNo() {
        return cardNo;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setCardNo(String cardNo) {
        this.cardNo = cardNo == null ? null : cardNo.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getPhone() {
        return phone;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setPhone(String phone) {
        this.phone = phone == null ? null : phone.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getPointsIdUnique() {
        return pointsIdUnique;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setPointsIdUnique(String pointsIdUnique) {
        this.pointsIdUnique = pointsIdUnique == null ? null : pointsIdUnique.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getChangeBills() {
        return changeBills;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeBills(String changeBills) {
        this.changeBills = changeBills == null ? null : changeBills.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Integer getChangeIntegral() {
        return changeIntegral;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeIntegral(Integer changeIntegral) {
        this.changeIntegral = changeIntegral;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Date getChangeDate() {
        return changeDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeDate(Date changeDate) {
        this.changeDate = changeDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getChangeWay() {
        return changeWay;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeWay(String changeWay) {
        this.changeWay = changeWay == null ? null : changeWay.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getChangeDetails() {
        return changeDetails;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeDetails(String changeDetails) {
        this.changeDetails = changeDetails == null ? null : changeDetails.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getUrOfflineBusinessType() {
        return urOfflineBusinessType;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setUrOfflineBusinessType(String urOfflineBusinessType) {
        this.urOfflineBusinessType = urOfflineBusinessType == null ? null : urOfflineBusinessType.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getOriginalChangeBills() {
        return originalChangeBills;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setOriginalChangeBills(String originalChangeBills) {
        this.originalChangeBills = originalChangeBills == null ? null : originalChangeBills.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getReversalChangeBills() {
        return reversalChangeBills;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setReversalChangeBills(String reversalChangeBills) {
        this.reversalChangeBills = reversalChangeBills == null ? null : reversalChangeBills.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Integer getChangeStatus() {
        return changeStatus;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getChangeStatusRemark() {
        return changeStatusRemark;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setChangeStatusRemark(String changeStatusRemark) {
        this.changeStatusRemark = changeStatusRemark == null ? null : changeStatusRemark.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Date getModifiedDate() {
        return modifiedDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public Boolean getValid() {
        return valid;
    }

    /**
     * 只读. 
     *
     * @mbg.generated
     */
    public void setValid(Boolean valid) {
        this.valid = valid;
    }
}
